@@ -165,7 +165,7 @@ init (GnomePilotDruid *gpd)
 	priv->device = g_new0 (GPilotDevice,1);
 
 	/* Gui stuff */
-	priv->xml = glade_xml_new (GLADEDATADIR "/gpilotd-capplet.glade", NULL);
+	priv->xml = glade_xml_new (GLADEDATADIR "/gpilotd-capplet.glade", NULL, NULL);
 	if (!priv->xml) {
 		g_message ("gnome-pilot-druid init(): Could not load the Glade XML file!");
 		goto error;
@@ -465,7 +465,7 @@ gpd_cradle_page_prepare (GnomeDruidPage *page, gpointer arg1, gpointer user_data
 	gboolean ready;
 	
 	ready = check_cradle_settings (gpd);
-	gnome_druid_set_buttons_sensitive (GNOME_DRUID (arg1), TRUE, ready, TRUE);
+	gnome_druid_set_buttons_sensitive (GNOME_DRUID (arg1), TRUE, ready, TRUE, FALSE);
 }
 
 static void
@@ -527,7 +527,7 @@ gpd_sync_page_prepare (GnomeDruidPage *page, gpointer arg1, gpointer user_data)
 	}
 
 	/* disable NEXT until we've synced */
-	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, FALSE, TRUE);
+	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, FALSE, TRUE, FALSE);
 }
 
 static gboolean
@@ -585,7 +585,7 @@ gpd_device_info_check (GtkEditable *editable, gpointer user_data)
 	priv = gpd->priv;
 	
 	ready = check_cradle_settings (gpd);
-	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, ready, TRUE);
+	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, ready, TRUE, FALSE);
 }
 
 static void
@@ -600,7 +600,7 @@ gpd_pilot_info_check (GtkEditable *editable, gpointer user_data)
 	if (GTK_TOGGLE_BUTTON (priv->pilot_info_no)->active)
 		ready = check_pilot_settings (gpd);
 
-	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, ready, TRUE);
+	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, ready, TRUE, FALSE);
 }
 
 static void
@@ -616,7 +616,7 @@ gpd_pilot_info_button (GtkToggleButton *toggle, gpointer user_data)
 	if (toggle->active)
 		ready = check_pilot_settings (gpd);
 
-	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, ready, TRUE);
+	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, ready, TRUE, FALSE);
 }
 
 static void 
@@ -630,7 +630,7 @@ gpd_request_completed (GnomePilotClient* client, const gchar *id, gint handle, g
 	if (handle != priv->handle)
 		return;
 	
-	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, TRUE, TRUE);
+	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, TRUE, TRUE, FALSE);
 }
 
 static void 
@@ -663,7 +663,7 @@ gpd_userinfo_requested (GnomePilotClient *gpc, const gchar *device, const GNOME_
 	g_snprintf (buf, sizeof (buf), "%d", priv->pilot->pilot_id);
 	gtk_entry_set_text (GTK_ENTRY (priv->pilot_id), buf);
 
-	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, TRUE, TRUE);
+	gnome_druid_set_buttons_sensitive (GNOME_DRUID (priv->druid), TRUE, TRUE, TRUE, FALSE);
 
 	g_free (text);
 	priv->handle = -1;
